@@ -1,14 +1,14 @@
 //! Module for managing running child processes
 
-use std::time::Duration;
 use std::sync::mpsc::channel;
+use std::time::Duration;
 
 use anyhow::anyhow;
-use log::{debug, error, trace, warn};
 use serde::{Deserialize, Serialize};
 use sysinfo::{Pid, ProcessExt, RefreshKind, Signal, System, SystemExt};
 use tokio::io::{AsyncBufReadExt, BufReader};
 use tokio::process::Child;
+use tracing::{debug, error, trace, warn};
 
 use crate::plugin_models::PactPluginManifest;
 
@@ -22,9 +22,10 @@ pub struct RunningPluginInfo {
 /// Running child process
 #[derive(Debug, Clone)]
 pub struct ChildPluginProcess {
-  child_pid: usize,
-  manifest: PactPluginManifest,
-  plugin_info: RunningPluginInfo
+  /// OS PID of the running process
+  pub child_pid: usize,
+  /// Info on the running plugin
+  pub plugin_info: RunningPluginInfo
 }
 
 impl ChildPluginProcess {
@@ -58,7 +59,6 @@ impl ChildPluginProcess {
                 Ok(plugin_info) => {
                   tx.send(Ok(ChildPluginProcess {
                     child_pid: child_pid as usize,
-                    manifest: mfso.clone(),
                     plugin_info
                   })).unwrap_or_default()
                 }
