@@ -2,13 +2,14 @@
 
 use std::collections::HashMap;
 use std::sync::Arc;
+use anyhow::anyhow;
 
 use async_trait::async_trait;
 use serde::{Deserialize, Serialize};
 use serde_json::Value;
 use tonic::metadata::MetadataValue;
 use tonic::transport::Channel;
-use tracing::trace;
+use tracing::{debug, trace};
 
 use crate::child_process::ChildPluginProcess;
 use crate::proto::*;
@@ -150,7 +151,7 @@ pub struct PactPlugin {
 impl PactPluginRpc for PactPlugin {
   /// Send an init request to the plugin process
   async fn init_plugin(&self, request: InitPluginRequest) -> anyhow::Result<InitPluginResponse> {
-    let channel = Channel::from_shared(format!("http://[::1]:{}", self.child.port()))?.connect().await?;
+    let channel = self.connect_channel().await?;
     let auth_str = self.child.plugin_info.server_key.as_str();
     let token = MetadataValue::from_str(auth_str)?;
     let mut client = PactPluginClient::with_interceptor(channel, move |mut req: tonic::Request<_>| {
@@ -163,7 +164,7 @@ impl PactPluginRpc for PactPlugin {
 
   /// Send a compare contents request to the plugin process
   async fn compare_contents(&self, request: CompareContentsRequest) -> anyhow::Result<CompareContentsResponse> {
-    let channel = Channel::from_shared(format!("http://[::1]:{}", self.child.port()))?.connect().await?;
+    let channel = self.connect_channel().await?;
     let auth_str = self.child.plugin_info.server_key.as_str();
     let token = MetadataValue::from_str(auth_str)?;
     let mut client = PactPluginClient::with_interceptor(channel, move |mut req: tonic::Request<_>| {
@@ -176,7 +177,7 @@ impl PactPluginRpc for PactPlugin {
 
   /// Send a configure contents request to the plugin process
   async fn configure_interaction(&self, request: ConfigureInteractionRequest) -> anyhow::Result<ConfigureInteractionResponse> {
-    let channel = Channel::from_shared(format!("http://[::1]:{}", self.child.port()))?.connect().await?;
+    let channel = self.connect_channel().await?;
     let auth_str = self.child.plugin_info.server_key.as_str();
     let token = MetadataValue::from_str(auth_str)?;
     let mut client = PactPluginClient::with_interceptor(channel, move |mut req: tonic::Request<_>| {
@@ -189,7 +190,7 @@ impl PactPluginRpc for PactPlugin {
 
   /// Send a generate content request to the plugin
   async fn generate_content(&self, request: GenerateContentRequest) -> anyhow::Result<GenerateContentResponse> {
-    let channel = Channel::from_shared(format!("http://[::1]:{}", self.child.port()))?.connect().await?;
+    let channel = self.connect_channel().await?;
     let auth_str = self.child.plugin_info.server_key.as_str();
     let token = MetadataValue::from_str(auth_str)?;
     let mut client = PactPluginClient::with_interceptor(channel, move |mut req: tonic::Request<_>| {
@@ -201,7 +202,7 @@ impl PactPluginRpc for PactPlugin {
   }
 
   async fn start_mock_server(&self, request: StartMockServerRequest) -> anyhow::Result<StartMockServerResponse> {
-    let channel = Channel::from_shared(format!("http://[::1]:{}", self.child.port()))?.connect().await?;
+    let channel = self.connect_channel().await?;
     let auth_str = self.child.plugin_info.server_key.as_str();
     let token = MetadataValue::from_str(auth_str)?;
     let mut client = PactPluginClient::with_interceptor(channel, move |mut req: tonic::Request<_>| {
@@ -213,7 +214,7 @@ impl PactPluginRpc for PactPlugin {
   }
 
   async fn shutdown_mock_server(&self, request: ShutdownMockServerRequest) -> anyhow::Result<ShutdownMockServerResponse> {
-    let channel = Channel::from_shared(format!("http://[::1]:{}", self.child.port()))?.connect().await?;
+    let channel = self.connect_channel().await?;
     let auth_str = self.child.plugin_info.server_key.as_str();
     let token = MetadataValue::from_str(auth_str)?;
     let mut client = PactPluginClient::with_interceptor(channel, move |mut req: tonic::Request<_>| {
@@ -257,6 +258,18 @@ impl PactPlugin {
       self.access_count);
     self.access_count
   }
+
+  async fn connect_channel(&self) -> anyhow::Result<Channel> {
+    let port = self.child.port();
+    match Channel::from_shared(format!("http://[::1]:{}", port))?.connect().await {
+      Ok(channel) => Ok(channel),
+      Err(err) => {
+        debug!("IP6 connection failed, will try IP4 address - {err}");
+        Channel::from_shared(format!("http://127.0.0.1:{}", port))?.connect().await
+          .map_err(|err| anyhow!(err))
+      }
+    }
+  }
 }
 
 /// Plugin configuration to add to the matching context for an interaction
